package cn.com.infosec.asn1.cms;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class KeyAgreeRecipientInfo extends ASN1Encodable {
   private DERInteger version;
   private OriginatorIdentifierOrKey originator;
   private ASN1OctetString ukm;
   private AlgorithmIdentifier keyEncryptionAlgorithm;
   private ASN1Sequence recipientEncryptedKeys;

   public KeyAgreeRecipientInfo(OriginatorIdentifierOrKey originator, ASN1OctetString ukm, AlgorithmIdentifier keyEncryptionAlgorithm, ASN1Sequence recipientEncryptedKeys) {
      KeyAgreeRecipientInfo var10000 = this;
      KeyAgreeRecipientInfo var10001 = this;
      KeyAgreeRecipientInfo var10002 = this;
      KeyAgreeRecipientInfo var10003 = this;
      KeyAgreeRecipientInfo var10004 = this;
      super();
      DERInteger var5;
      var5 = new DERInteger.<init>(3);
      var10004.version = var5;
      var10003.originator = originator;
      var10002.ukm = ukm;
      var10001.keyEncryptionAlgorithm = keyEncryptionAlgorithm;
      var10000.recipientEncryptedKeys = recipientEncryptedKeys;
   }

   public KeyAgreeRecipientInfo(ASN1Sequence seq) {
      this.version = (DERInteger)seq.getObjectAt(0);
      byte var2 = 2;
      this.originator = OriginatorIdentifierOrKey.getInstance((ASN1TaggedObject)seq.getObjectAt(1), true);
      if (seq.getObjectAt(var2) instanceof ASN1TaggedObject) {
         byte var10002 = var2;
         var2 = 3;
         this.ukm = ASN1OctetString.getInstance((ASN1TaggedObject)seq.getObjectAt(var10002), true);
      }

      KeyAgreeRecipientInfo var10000 = this;
      KeyAgreeRecipientInfo var4 = this;
      int var3 = var2 + 1;
      var4.keyEncryptionAlgorithm = AlgorithmIdentifier.getInstance(seq.getObjectAt(var2));
      var10000.recipientEncryptedKeys = (ASN1Sequence)seq.getObjectAt(var3);
   }

   public static KeyAgreeRecipientInfo getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public static KeyAgreeRecipientInfo getInstance(Object obj) {
      if (obj != null && !(obj instanceof KeyAgreeRecipientInfo)) {
         if (obj instanceof ASN1Sequence) {
            return new KeyAgreeRecipientInfo((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Illegal object in KeyAgreeRecipientInfo: " + obj.getClass().getName());
         }
      } else {
         return (KeyAgreeRecipientInfo)obj;
      }
   }

   public DERInteger getVersion() {
      return this.version;
   }

   public OriginatorIdentifierOrKey getOriginator() {
      return this.originator;
   }

   public ASN1OctetString getUserKeyingMaterial() {
      return this.ukm;
   }

   public AlgorithmIdentifier getKeyEncryptionAlgorithm() {
      return this.keyEncryptionAlgorithm;
   }

   public ASN1Sequence getRecipientEncryptedKeys() {
      return this.recipientEncryptedKeys;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.version);
      OriginatorIdentifierOrKey var2 = this.originator;
      var10001.add(new DERTaggedObject(true, 0, var2));
      ASN1OctetString var4;
      if ((var4 = this.ukm) != null) {
         DERTaggedObject var3;
         var3 = new DERTaggedObject.<init>(true, 1, var4);
         var1.add(var3);
      }

      var1.add(this.keyEncryptionAlgorithm);
      var1.add(this.recipientEncryptedKeys);
      return new DERSequence(var1);
   }
}
